@@ -29,12 +29,15 @@ G_BEGIN_DECLS
 #define GST_GL_HAVE_PLATFORM_CGL 0
 #define GST_GL_HAVE_PLATFORM_EAGL 0
 
+#define GST_GL_HAVE_DMABUF 1
+
 #define GST_GL_HAVE_GLEGLIMAGEOES 1
 #define GST_GL_HAVE_GLCHAR 1
 #define GST_GL_HAVE_GLSIZEIPTR 1
 #define GST_GL_HAVE_GLINTPTR 1
 #define GST_GL_HAVE_GLSYNC 1
 #define GST_GL_HAVE_GLUINT64 1
+#define GST_GL_HAVE_GLINT64 1
 
 
 G_END_DECLS
